﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.OleDb;
using System.Drawing;
using System.Drawing.Printing;
using System.Text;
using System.Windows.Forms;
using C1.Win.C1FlexGrid;
using System.Collections;

namespace C1FlexGridPrintPreview
{
    public partial class Form1 : Form
    {
        List<C1FlexGrid> fxCollection;
        public Form1()
        {
            InitializeComponent();

            // load some data into the grid
            // create data source
            string sql = "select * from customers";
            string conn = GetConnectionString();
            System.Data.OleDb.OleDbDataAdapter da = new System.Data.OleDb.OleDbDataAdapter(sql, conn);
            DataTable dt = new DataTable();
            da.Fill(dt);

            // bind grid
            _flex.DataSource = dt;
            _flex.Tag = sql;
            //_flex.ShowCursor = true;

            // bind the other grid
            sql = "select * from employees";
            da = new System.Data.OleDb.OleDbDataAdapter(sql, conn);
            dt = new DataTable();
            da.Fill(dt);
            c1FlexGrid1.AutoResize = false;
            c1FlexGrid1.DataSource = dt;
            c1FlexGrid1.Tag = sql;

            fxCollection = new List<C1FlexGrid>();
            fxCollection.Add(_flex);
            fxCollection.Add(c1FlexGrid1);
        }

        // northwind installed here by c1 setup, adjust if needed.
        static string GetConnectionString()
        {
            string path = Environment.GetFolderPath(Environment.SpecialFolder.Personal) + @"\ComponentOne Samples\Common";
            string conn = @"provider=microsoft.jet.oledb.4.0;data source={0}\C1NWind.mdb;";
            return string.Format(conn, path);
        }

        void _btnCustom_Click(object sender, EventArgs e)
        {
            _flexCurrent = 0;
            // create regular PrintDocument, attach event handlers
            var doc = new PrintDocument();
            doc.PrintPage += doc_PrintPage;
            doc.EndPrint += doc_EndPrint;

            // show new document in Custom print preview dialog
            using (var dlg = new C1PrintPreview.C1PrintPreviewDialog())
            {
                dlg.Document = doc;
                dlg.ShowDialog();
            }
        }

        PrintDocumentGridRenderer _pdr;
        int _flexCurrent;
        void doc_PrintPage(object sender, PrintPageEventArgs e)
        {
            if (_flexCurrent == 0 || _pdr.CurrentPage >= _pdr.PageCount)
            {
                _pdr = new PrintDocumentGridRenderer(fxCollection[_flexCurrent]);
                _pdr.Options = PrintGridFlags.ActualSize;

                // print header on first page of c1flexgrid
                if (_pdr.CurrentPage == 0)
                {
                    using (var font = new Font("Verdana", 14, FontStyle.Bold))
                    {
                        // render the title
                        var title = fxCollection[_flexCurrent].Tag.ToString();
                        e.Graphics.DrawString(title, font, Brushes.Black, e.MarginBounds.Location);


                        // push the grid rendering down to make room for the title
                        _pdr.FirstPageY =
                            e.MarginBounds.Location.Y +
                            (int)e.Graphics.MeasureString(title, font).Height;
                    }
                }
                _flexCurrent++;
            }

            //// print the current page
            _pdr.PrintPage(e);

            // print a header on all pages
            var header = string.Format("Page {0}/{1}", _pdr.CurrentPage, _pdr.PageCount);
            var rc = new Rectangle(e.MarginBounds.X, 0, e.MarginBounds.Width, e.MarginBounds.Bottom);

            using (var font = new Font("Verdana", 10, FontStyle.Bold))
            {
                e.Graphics.DrawLine(Pens.Blue, rc.X, rc.Bottom, rc.Right, rc.Bottom);
                e.Graphics.DrawString(header, font, Brushes.Blue, e.MarginBounds.Left, e.MarginBounds.Bottom);//, fmt);

            }

            e.HasMorePages = _pdr.CurrentPage < _pdr.PageCount || _flexCurrent < fxCollection.Count;
        }
        void doc_EndPrint(object sender, PrintEventArgs e)
        {
            // done, we no longer need the PrintDocumentGridRenderer.
            _pdr = null;
        }
    }

}
